function SetContains(set, key)
    return set[key] ~= nil
end

function IsAnimaItem(itemLink)
    local spellName, spellId = GetItemSpell(itemLink);

    return SetContains(AnimaShortage.Data.AnimaSpellValues, spellId)
end

function GetAnimaItemValue(item)
    local spellName, spellId = GetItemSpell(item);

    if spellName and spellId then
        if SetContains(AnimaShortage.Data.AnimaSpellValues, spellId) then
            return AnimaShortage.Data.AnimaSpellValues[spellId]
        end
    end

end

function CountAnimaValuesForItem(item, count)
    local animaValue = GetAnimaItemValue(item)

    if animaValue then
        if count then
            return animaValue * count
        else
            return animaValue * GetItemCount(item)
        end
    end
    return 0;
end

function CalculateAnimaInInventory()
    local totalAnima = 0;
    for bag = 0, 4 do
        for slot = 1, GetContainerNumSlots(bag) do
            local item = GetContainerItemLink(bag, slot)
            if item then
                totalAnima = totalAnima + CountAnimaValuesForItem(item)
            end
        end
    end
    return totalAnima;
end

function ShowTotalAnimaInBags()
    local animaInInventory = CalculateAnimaInInventory();

    if animaInInventory > 0 then
        GameTooltip:AddLine(animaInInventory .. AnimaShortage.Data.DisplayStrings["AnimaInBags"], 0.6, 0.6, 0.6);
    else
        GameTooltip:AddLine(AnimaShortage.Data.DisplayStrings["NoAnimaInBags"], 0.6, 0.6, 0.6);
    end
    GameTooltip:Show()

end

function DrawQuestLogRewardAnimaTotal(frame)
    if frame:GetName() ~= nil and string.find(frame:GetName(), "MapQuestInfoRewardsFrameQuestInfoItem") then
        local name, texture, quantity, quality, isUsable, itemID = GetQuestLogRewardInfo(1);

        if isUsable then
            local result = 0;
            local animavalue = GetAnimaItemValue(itemID);
            if animavalue then
                result = animavalue * quantity;
                GameTooltip:AddLine(result .. AnimaShortage.Data.DisplayStrings["Total"], 0.6, 0.6, 0.6);
                return true;
            end
        end
    end
end

function DrawAnimaCountIfFrameHasQuantity(frame, itemLink)
    if frame.Quantity then
        local quantity = tonumber(frame.Quantity:GetText());
        local result = 0;
        local animavalue = GetAnimaItemValue(itemLink);
        if animavalue then
            result = animavalue * quantity;
            GameTooltip:AddLine(result .. AnimaShortage.Data.DisplayStrings["Total"], 0.6, 0.6, 0.6);
            return true
        end
    end
end

function DrawInventoryItemAnimaTotal(frame, itemLink, count)
    local tooltip = tooltip or GameTooltip
    local totalAnimaInStack = CountAnimaValuesForItem(itemLink, count)

    if totalAnimaInStack > 0 then
        tooltip:AddLine(totalAnimaInStack .. AnimaShortage.Data.DisplayStrings["Total"], 0.6, 0.6, 0.6);
        tooltip:Show()
    end
end

OnTooltipSetItemDrawFunctions = {DrawAnimaCountIfFrameHasQuantity, DrawQuestLogRewardAnimaTotal,
                                 DrawInventoryItemAnimaTotal}

function DrawTooltipAnimaDefault(self, link)
    local frame = self:GetOwner();
    for i, drawFunction in ipairs(OnTooltipSetItemDrawFunctions) do
        local drawn = drawFunction(frame, link)
        if drawn then
            break
        end
    end
end
