AnimaShortage.Compatibility = {
    ArkInventory = {
        name = "ArkInventory",
        detected = false,
        Version = 30946,
        onLoad = function()
            AnimaShortage.Compatibility.ArkInventory.detected = true;

            -- Cheeky check to see if ArkInventory has gone far ahead without warning on every little bugfix
            local version, global = ArkInventory.API.Version()
            if version - AnimaShortage.Compatibility.ArkInventory.Version >= 3 then
                AnimaShortage.Warning(AnimaShortage.Data.DisplayStrings["Compatibility.ArkInventoryAhead"])
            end

            hooksecurefunc(ArkInventory.API, "ReloadedTooltipReady", function(tooltip, fn, ...)
                if _G["GameTooltipTextLeft" .. 1]:GetText() == AnimaShortage.Data.ReservoirAnima then
                    AnimaShortage.Patches.ArkInventory.ShowTotalAnimaInBags()
                end
            end)
        end
    }
}

function AnimaShortage.Patches.ArkInventory.ShowTotalAnimaInBags()
    local animaInInventory = CalculateAnimaInInventory();

    if animaInInventory > 0 then
        _G["GameTooltipTextLeft" .. 5]:SetFormattedText("|c" .. AnimaShortage.Data.Colors["Gray"] .. "%s|r",
            animaInInventory .. AnimaShortage.Data.DisplayStrings["AnimaInBags"] .. "\n")
    else
        _G["GameTooltipTextLeft" .. 5]:SetFormattedText("|c" .. AnimaShortage.Data.Colors["Gray"] .. "%s|r",
            AnimaShortage.Data.DisplayStrings["NoAnimaInBags"] .. "\n")
    end
    GameTooltip:Show()

end

function AnimaShortage.Patches.ArkInventory.DrawToolTipAnima(self, link)
    local frame = self:GetOwner();
    if frame:GetName() and string.find(frame:GetName(), "MapQuestInfoRewardsFrameQuestInfoItem") then
        DrawQuestLogRewardAnimaTotal(frame);
        return
    end

    if frame:GetName() then
        local data = ArkInventory.API.ItemFrameItemTableGet(self:GetOwner())

        for i, drawFunction in ipairs(OnTooltipSetItemDrawFunctions) do
            local drawn = drawFunction(frame, link, data.count)
            if drawn then
                break
            end
        end
    end
    return
end

local EventFrame = CreateFrame('Frame')
EventFrame:RegisterEvent('ADDON_LOADED')
EventFrame:SetScript('OnEvent', function(self, event, ...)
    if self[event] then
        self[event](self, ...)
    end
end)

function EventFrame:ADDON_LOADED(name)
    for k, combatibilityData in pairs(AnimaShortage.Compatibility) do
        if name == combatibilityData.name then
            if combatibilityData.onLoad then
                combatibilityData.onLoad()
                AnimaShortage.Message(AnimaShortage.Data.DisplayStrings["Compatibility.Detected"] .. name)

                -- Note: this only works as long as we have one addon in this list
                self:UnregisterEvent('ADDON_LOADED')
                self.ADDON_LOADED = nil
            end
        end
    end

end
